==========================================================
``mosaik.simulator`` --- Coordinate and execute simulators
==========================================================

.. automodule:: mosaik.simulator

.. autofunction:: run

.. autofunction:: sim_process

.. autofunction:: step_required

.. autofunction:: wait_for_dependencies

.. autofunction:: get_input_data

.. autofunction:: step

.. autofunction:: get_outputs

.. autofunction:: get_progress
